===============================
Django OSM Field
===============================

.. image:: https://badge.fury.io/py/django-osm-field.png
    :target: http://badge.fury.io/py/django-osm-field

Django OpenStreetMap Field

* Free software: BSD license
* Documentation: http://django-osm-field.rtfd.org.

Features
--------

* TODO
